package cn.cslg.pas.mapper;

import cn.cslg.pas.common.model.vo.PermissionRecordTrendVO;
import cn.cslg.pas.common.model.vo.ProductMarketDataTrendVO;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 专利价值曲线的Mapper层
 *
 * @Author xiexiang
 * @Date 2023/3/15
 */
@Repository
public interface PatentMarketDataMapper {

    /**
     * 传入专利号、营销地区saleArea，返回数据
     *
     * @param saleArea 营销地区
     * @param patentNoList 专利号（必需）
     * @return 返回查询到的数据
     */
    List<ProductMarketDataTrendVO> patentQueryByYear(List patentNoList, String saleArea,Integer tenantId);

    List<ProductMarketDataTrendVO> patentQueryBySeason(List patentNoList, String saleArea,Integer tenantId);

    List<ProductMarketDataTrendVO> patentQueryByMonth(List patentNoList, String saleArea,Integer tenantId);

    /**
     * 传入专利号，查询时间和许可历史费用
     * @param patentNoList 专利号（必需）
     * @return 返回查询到的数据
     */
    List<PermissionRecordTrendVO> PRDataQueryByYear(List patentNoList,Integer tenantId);

    List<PermissionRecordTrendVO> PRDataQueryBySeason(List patentNoList,Integer tenantId);

    List<PermissionRecordTrendVO> PRDataQueryByMonth(List patentNoList,Integer tenantId);

}
